@@ -74,8 +74,8 @@ class Markdown:
         # Replace each SMP code point with a surrogate pair
         return cls.SMP_RE.sub(
             lambda match:  # Split SMP in two surrogates
-            "".join(chr(i) for i in unpack("<HH", match.group().encode("utf-16le")))
-            , text
+            "".join(chr(i) for i in unpack("<HH", match.group().encode("utf-16le"))),
+            text
         )
 
     @staticmethod
