@@ -242,8 +242,9 @@ class Auth:
                         set_client_dh_params_answer.__class__.__name__
                     )
                 )
-            except Exception as e:  # TODO: Too broad exception clause
+            except Exception as e:
                 log.warning("Auth key creation failed. Let's try again: {}".format(repr(e)))
+                time.sleep(1)
                 continue
             else:
                 return auth_key
